# PyDemod
PyDemod is a Python demodulation/modulation library usng NumPy. Orignally made by Christophe Jacquet. Chris's version is fine however its a bit old, so I edited the code to be compatible and made it to be easily installabe

# Originals
[README](/OLD_README.md)
[ChristopheJacquet/Pydemod](https://github.com/ChristopheJacquet/Pydemod)